@@ -1,7 +1,14 @@
 import requests
 import aiohttp
 
-from python3_anticaptcha import get_balance_url, incorrect_captcha_url, get_queue_status_url
+from python3_anticaptcha import (
+    get_balance_url,
+    get_app_stats_url,
+    incorrect_captcha_url,
+    get_queue_status_url,
+)
+
+mods = ("errors", "views", "downloads", "users", "money")
 
 
 class AntiCaptchaControl:
@@ -11,7 +18,7 @@ class AntiCaptchaControl:
         :param anticaptcha_key: Ключ антикапчи
         """
         self.ANTICAPTCHA_KEY = anticaptcha_key
-    
+
     def __enter__(self):
         return self
 
@@ -20,30 +27,47 @@ class AntiCaptchaControl:
             return False
         return True
 
-    def get_balance(self):
+    def get_balance(self) -> dict:
         """
         Получение баланса аккаунта
         :return: Возвращает актуальный баланс
         """
-        answer = requests.post(get_balance_url, json={'clientKey': self.ANTICAPTCHA_KEY})
+        answer = requests.post(
+            get_balance_url, json={"clientKey": self.ANTICAPTCHA_KEY}
+        )
 
         return answer.json()
 
-    def complaint_on_result(self, reported_id: int):
+    def get_app_stats(self, softId: int, mode: str = "errors") -> dict:
+        """
+        Получение статистики приложения
+        :return: Возвращает актуальный баланс
+        """
+        if mode not in mods:
+            raise ValueError(
+                "\nПередан неверный `mode`."
+                f"\n\tВозможные варинты: {mods}. Вы передали - `{mode}`"
+                f"\nWrong `mode` parameter. Valid params: {mods}."
+                f"\n\tYour param - `{mode}`"
+            )
+        payload = {"clientKey": self.ANTICAPTCHA_KEY, "softId": softId, "mode": mode}
+        answer = requests.post(get_app_stats_url, json=payload)
+
+        return answer.json()
+
+    def complaint_on_result(self, reported_id: int) -> dict:
         """
         Позволяет отправить жалобу на неправильно решённую капчу.
         :param reported_id: Отправляете ID капчи на которую нужно пожаловаться
         :return: Возвращает True/False, в зависимости от результата
         """
-        payload = {'clientKey': self.ANTICAPTCHA_KEY,
-                   'taskId': reported_id,
-                   }
+        payload = {"clientKey": self.ANTICAPTCHA_KEY, "taskId": reported_id}
 
         answer = requests.post(incorrect_captcha_url, json=payload)
 
         return answer.json()
 
-    def get_queue_status(self, queue_id: int):
+    def get_queue_status(self, queue_id: int) -> dict:
         """
         Получение информации о загрузке очереди, в зависимости от ID очереди.
 
@@ -69,9 +93,7 @@ class AntiCaptchaControl:
         :param queue_id: Номер очереди
         :return: JSON-объект
         """
-        payload = {
-            "queueId": queue_id
-        }
+        payload = {"queueId": queue_id}
 
         answer = requests.post(get_queue_status_url, json=payload)
 
@@ -85,7 +107,7 @@ class aioAntiCaptchaControl:
         :param anticaptcha_key: Ключ антикапчи
         """
         self.ANTICAPTCHA_KEY = anticaptcha_key
-    
+
     def __enter__(self):
         return self
 
@@ -94,29 +116,46 @@ class aioAntiCaptchaControl:
             return False
         return True
 
-    async def get_balance(self):
+    async def get_balance(self) -> dict:
         """
         Получение баланса аккаунта
         :return: Возвращает актуальный баланс
         """
         async with aiohttp.ClientSession() as session:
-            async with session.post(get_balance_url, json={'clientKey': self.ANTICAPTCHA_KEY}) as resp:
+            async with session.post(
+                get_balance_url, json={"clientKey": self.ANTICAPTCHA_KEY}
+            ) as resp:
                 return await resp.json()
 
-    async def complaint_on_result(self, reported_id: int):
+    async def get_app_stats(self, softId: int, mode: str = "errors") -> dict:
+        """
+        Получение баланса аккаунта
+        :return: Возвращает актуальный баланс
+        """
+        if mode not in mods:
+            raise ValueError(
+                "\nПередан неверный `mode`."
+                f"\n\tВозможные варинты: {mods}. Вы передали - `{mode}`"
+                f"\nWrong `mode` parameter. Valid params: {mods}."
+                f"\n\tYour param - `{mode}`"
+            )
+        payload = {"clientKey": self.ANTICAPTCHA_KEY, "softId": softId, "mode": mode}
+        async with aiohttp.ClientSession() as session:
+            async with session.post(get_app_stats_url, json=payload) as resp:
+                return await resp.json()
+
+    async def complaint_on_result(self, reported_id: int) -> dict:
         """
         Позволяет отправить жалобу на неправильно решённую капчу.
         :param reported_id: Отправляете ID капчи на которую нужно пожаловаться
         :return: Возвращает True/False, в зависимости от результата
         """
-        payload = {'clientKey': self.ANTICAPTCHA_KEY,
-                   'taskId': reported_id,
-                   }
+        payload = {"clientKey": self.ANTICAPTCHA_KEY, "taskId": reported_id}
         async with aiohttp.ClientSession() as session:
             async with session.post(incorrect_captcha_url, json=payload) as resp:
                 return await resp.json()
 
-    async def get_queue_status(self, queue_id: int):
+    async def get_queue_status(self, queue_id: int) -> dict:
         """
         Получение информации о загрузке очереди, в зависимости от ID очереди.
 
@@ -142,11 +181,8 @@ class aioAntiCaptchaControl:
         :param queue_id: Номер очереди
         :return: JSON-объект
         """
-        payload = {
-            "queueId": queue_id
-        }
+        payload = {"queueId": queue_id}
 
         async with aiohttp.ClientSession() as session:
             async with session.post(get_queue_status_url, json=payload) as resp:
                 return await resp.json()
-
